@@ -3,7 +3,7 @@
 #define EPS pow(10, -9)
 
 void probSxSyCond(int *vx, int *vy, double *logpxy, double *logj, double *factj,
-		  int nx, int ny, int nux, int nuy, int nuxy, int *ixy,
+		  int numx, int numy, int nux, int nuy, int nuxy, int *ixy,
 		  int *iyx, double combx, double comby, double *sprob,
 		  int *mmax, int nm);
 double probSxSy(double *logr, double *log1r, double prob, double *sprob, int nm,
